<!DOCTYPE html>
<html>
    <head>
        <title>page not found</title>
        <link rel="stylesheet" href="{{ url_for('static', filename='css/main.css') }}">
    </head>
    <body>
        <h1>404: Page Not Found</h1>
        <p>Click to go back to <a href="/">home</a></p>
    </body>
</html>
